@@ -7,6 +7,7 @@
 #' @param authors is a character vector. It contains the the authors' names list for which you want to calculate the H-index. The aurgument has the form C("SURNAME1 N","SURNAME2 N",...), in other words, for each author: surname and initials separated by one blank space. 
 #' i.e for the auhtors SEMPRONIO TIZIO CAIO and ARIA MASSIMO \code{authors} argument is \code{authors = c("SEMPRONIO TC", "ARIA M")}.
 #' @param sep is the field separator character. This character separates auhtors in each string of AU column of the bibiographic data frame. The default is \code{sep = ";"}.
+#' @param years is a integer. It indicates the number of years to consider for Hindex calculation. Default is 10.
 #' @return an object of \code{class} "list". It contains two elements: H is a data frame with h-index, g-index and m-index for each author; CitationList is a list with the bibliographic collection for each author.
 #'
 #' 
@@ -39,7 +40,13 @@
 #' 
 #' @export
 
-Hindex <- function(M, authors, sep = ";"){
+Hindex <- function(M, authors, sep = ";",years=10){
+  
+  M$TC=as.numeric(M$TC)
+  M$PY=as.numeric(M$PY)
+  Today=as.numeric(substr(Sys.time(),1,4))
+  past=Today-years
+  if (min(M$PY)<past){M=M[M$PY>=past,]}
   
   TC2=NULL
    ## identify manuscripts of the author
@@ -47,13 +54,16 @@ Hindex <- function(M, authors, sep = ";"){
   AU=gsub(","," ",AU)
   AU=gsub("  "," ",AU)
  
-  H=data.frame(Author=authors,h_index=0,g_index=0,m_index=0)
+  H=data.frame(Author=authors,h_index=0,g_index=0,m_index=0,TC=0,NP=0)
   TotalCitations=list()
   for (j in 1:length(authors)){
     author=authors[j]
     ind=which(regexpr(author,AU)!=-1)
-    range=as.numeric(format(Sys.Date(),'%Y'))-min(as.numeric(M$PY[ind]))+1
+    
     if (length(ind)>0){
+    range=as.numeric(format(Sys.Date(),'%Y'))-min(as.numeric(M$PY[ind]))+1
+    H[j,6]=length(ind)
+    H[j,5]=sum(M$TC[ind])
     TC=sort(as.numeric(M$TC[ind]))
     TCC=sort(as.numeric(M$TC[ind]),decreasing = TRUE)
       for (i in 1:length(TC)){
@@ -65,8 +75,11 @@ Hindex <- function(M, authors, sep = ";"){
       }
     }
     #TotalCitations[[j]]=data.frame(Year=as.numeric(M$PY[ind]),TC,Year2=sort(as.numeric(M$PY[ind])),TC2)
-    TotalCitations[[j]]=data.frame(Authors=substr(M$AU[ind], 1, 30),Journal=substr(M$SO[ind], 1, 30),Year=as.numeric(M$PY[ind]),TotalCitation=TC)
-  }
+    if (length(ind)>0){
+    df=data.frame(Authors=substr(M$AU[ind], 1, 30),Journal=substr(M$SO[ind], 1, 30),Year=as.numeric(M$PY[ind]),TotalCitation=M$TC[ind])
+    TotalCitations[[j]]=df[order(df$TotalCitation),]
+    }
+    }
   results=list(H=H,CitationList=TotalCitations)
   return(results)
   }
\ No newline at end of file
