@@ -17,7 +17,7 @@
 #' AuthorsFrac \tab      \tab the authors' frequency distribution (fractionalized)\cr
 #' FirstAuthors \tab      \tab first author of each manuscript\cr
 #' nAUperPaper \tab      \tab the number of authors per manuscript\cr
-#' Apparences \tab      \tab the number of author apparences\cr
+#' Appearances \tab      \tab the number of author appearances\cr
 #' nAuthors \tab       \tab the number of authors\cr
 #' AuMultiAuthoredArt \tab      \tab the number of authors of multi authored articles\cr
 #' MostCitedPapers \tab      \tab The list of manuscripts sorted by citations\cr
@@ -190,7 +190,7 @@ results=list(Articles=dim(M)[1],             # Articles
              AuthorsFrac=Authors_frac,       # Authors' frequency distribution (fractionalized)
              FirstAuthors=unlist(FirstAuthors),# First Author's list
              nAUperPaper=nAU,                # N. Authors per Paper
-             Apparences=sum(nAU),            # Author apparences
+             Appearances=sum(nAU),            # Author appearances
              nAuthors=dim(Authors),          # N. of Authors
              AuMultiAuthoredArt=AuMultiAuthoredArt, # N. of Authors of multi authored articles
              MostCitedPapers=MostCitedPapers,# Papers sorted by citations
